# GCPDS - utils

This package is a set of useful Python scripts for *Database handler*, *EEG filtering*, *Data visualizations* and *Package management*.

## Installation


```python
pip install -U git+https://github.com/UN-GCPDS/python-gcpds.utils.git
```
